@@ -80,10 +80,10 @@ class LocalController(LocalActor, IMgmtController):
 
         return None
 
-    def get_pool_info(self, *, broker: ID, id_token: str) -> List[PoolInfoAvro]:
+    def get_pool_info(self, *, broker: ID, id_token: str, level: int) -> List[PoolInfoAvro]:
         self.clear_last()
         try:
-            result = self.manager.get_pool_info(broker=broker, caller=self.auth, id_token=id_token)
+            result = self.manager.get_pool_info(broker=broker, caller=self.auth, id_token=id_token, level=level)
             self.last_status = result.status
 
             if result.status.get_code() == 0:
